ellipsis property

bool ellipsis
final

When true, child is constrained to one line, ellipsized, and wrapped in a Tooltip showing tooltip (or the child's textual value).

Implementation

final bool ellipsis;