visible property
Whether this column is rendered. When false, the column is skipped during layout and no header/body cells are created. Defaults to true.
Implementation
final bool visible;
Whether this column is rendered. When false, the column is skipped during layout and no header/body cells are created. Defaults to true.
final bool visible;