SummerSortSpec class

A single active sort entry (used for multi-column sort).

Constructors

SummerSortSpec({required String key, bool ascending = true})
const

Properties

ascending bool
Sort direction: true = ascending, false = descending.
final
hashCode int
The hash code for this object.
no setteroverride
key String
Column key being sorted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override