SummerTreeNode class
A node in a hierarchical (tree) table.
Constructors
-
SummerTreeNode({Object? key, List<
SummerTreeNode> children = const []}) -
const
Properties
-
children
→ List<
SummerTreeNode> -
Child nodes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Object?
-
Stable identity (combined with ancestors for uniqueness).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited