fixedColumnShadow property
Shadow drawn at the inner edge of pinned columns when the middle band is horizontally scrollable. Null disables the shadow.
Implementation
final BoxShadow? fixedColumnShadow;
Shadow drawn at the inner edge of pinned columns when the middle band is horizontally scrollable. Null disables the shadow.
final BoxShadow? fixedColumnShadow;