sortInactiveIcon property
Icon shown when a sortable column is not active. Defaults to a neutral indicator; null is allowed.
Implementation
final Widget? sortInactiveIcon;
Icon shown when a sortable column is not active. Defaults to a neutral indicator; null is allowed.
final Widget? sortInactiveIcon;