builder property
Builds the expansion panel shown beneath the expanded row.
Implementation
final Widget Function(BuildContext context, int rowIndex) builder;
Builds the expansion panel shown beneath the expanded row.
final Widget Function(BuildContext context, int rowIndex) builder;