SummerRowSelection class

Row-selection configuration (controlled).

The caller owns selectedKeys and updates them in onChanged. For stable selection across row mutations, ensure your data source implements SummerDataTableSource.rowKey with a stable identifier.

Constructors

SummerRowSelection({SummerSelectionType type = SummerSelectionType.checkbox, Set<Object?> selectedKeys = const <Object?>{}, ValueChanged<Set<Object?>>? onChanged, double width = 48.0, bool disabled = false, bool rowDisabler(Object? rowKey)?})
const

Properties

disabled bool
When true, all row checkboxes render disabled and ignore taps.
final
hashCode int
The hash code for this object.
no setterinherited
onChanged ValueChanged<Set<Object?>>?
Invoked with the new key set when the selection changes.
final
rowDisabler bool Function(Object? rowKey)?
Optional callback that returns true when the row with rowKey should have its selection control disabled. When set, it is checked in addition to disabled (either can disable a row).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedKeys Set<Object?>
Currently selected row keys.
final
type SummerSelectionType
Selection mode.
final
width double
Width of the selection column.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited